@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,25 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
+import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.api import service_pb2 as service  # type: ignore
+from google.api import service_pb2  # type: ignore
 from google.cloud.servicemanagement_v1.types import resources
 from google.cloud.servicemanagement_v1.types import servicemanager
-from google.longrunning import operations_pb2 as operations  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 from .base import ServiceManagerTransport, DEFAULT_CLIENT_INFO
 from .grpc import ServiceManagerGrpcTransport
 
@@ -40,7 +37,8 @@ from .grpc import ServiceManagerGrpcTransport
 class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     """gRPC AsyncIO backend transport for ServiceManager.
 
-    `Google Service Management API </service-management/overview>`__
+    `Google Service Management
+    API <https://cloud.google.com/service-management/overview>`__
 
     This class defines the same methods as the primary client, so the
     primary client can load the underlying transport implementation
@@ -57,7 +55,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def create_channel(
         cls,
         host: str = "servicemanagement.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -84,13 +82,15 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
         Returns:
             aio.Channel: A gRPC AsyncIO channel object.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -98,7 +98,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
         self,
         *,
         host: str = "servicemanagement.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
@@ -108,11 +108,13 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -148,6 +150,8 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -171,7 +175,6 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             # If a channel was explicitly provided, set it.
             self._grpc_channel = channel
             self._ssl_channel_credentials = None
-
         else:
             if api_mtls_endpoint:
                 host = api_mtls_endpoint
@@ -201,6 +204,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -316,7 +320,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def create_service(
         self,
     ) -> Callable[
-        [servicemanager.CreateServiceRequest], Awaitable[operations.Operation]
+        [servicemanager.CreateServiceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create service method over gRPC.
 
@@ -339,7 +343,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["create_service"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/CreateService",
                 request_serializer=servicemanager.CreateServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_service"]
 
@@ -347,7 +351,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def delete_service(
         self,
     ) -> Callable[
-        [servicemanager.DeleteServiceRequest], Awaitable[operations.Operation]
+        [servicemanager.DeleteServiceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the delete service method over gRPC.
 
@@ -374,7 +378,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["delete_service"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/DeleteService",
                 request_serializer=servicemanager.DeleteServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_service"]
 
@@ -382,7 +386,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def undelete_service(
         self,
     ) -> Callable[
-        [servicemanager.UndeleteServiceRequest], Awaitable[operations.Operation]
+        [servicemanager.UndeleteServiceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the undelete service method over gRPC.
 
@@ -408,7 +412,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["undelete_service"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/UndeleteService",
                 request_serializer=servicemanager.UndeleteServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["undelete_service"]
 
@@ -445,7 +449,9 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     @property
     def get_service_config(
         self,
-    ) -> Callable[[servicemanager.GetServiceConfigRequest], Awaitable[service.Service]]:
+    ) -> Callable[
+        [servicemanager.GetServiceConfigRequest], Awaitable[service_pb2.Service]
+    ]:
         r"""Return a callable for the get service config method over gRPC.
 
         Gets a service configuration (version) for a managed
@@ -465,7 +471,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["get_service_config"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/GetServiceConfig",
                 request_serializer=servicemanager.GetServiceConfigRequest.serialize,
-                response_deserializer=service.Service.FromString,
+                response_deserializer=service_pb2.Service.FromString,
             )
         return self._stubs["get_service_config"]
 
@@ -473,7 +479,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def create_service_config(
         self,
     ) -> Callable[
-        [servicemanager.CreateServiceConfigRequest], Awaitable[service.Service]
+        [servicemanager.CreateServiceConfigRequest], Awaitable[service_pb2.Service]
     ]:
         r"""Return a callable for the create service config method over gRPC.
 
@@ -501,7 +507,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["create_service_config"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/CreateServiceConfig",
                 request_serializer=servicemanager.CreateServiceConfigRequest.serialize,
-                response_deserializer=service.Service.FromString,
+                response_deserializer=service_pb2.Service.FromString,
             )
         return self._stubs["create_service_config"]
 
@@ -509,7 +515,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def submit_config_source(
         self,
     ) -> Callable[
-        [servicemanager.SubmitConfigSourceRequest], Awaitable[operations.Operation]
+        [servicemanager.SubmitConfigSourceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the submit config source method over gRPC.
 
@@ -541,7 +547,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["submit_config_source"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/SubmitConfigSource",
                 request_serializer=servicemanager.SubmitConfigSourceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["submit_config_source"]
 
@@ -609,7 +615,8 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def create_service_rollout(
         self,
     ) -> Callable[
-        [servicemanager.CreateServiceRolloutRequest], Awaitable[operations.Operation]
+        [servicemanager.CreateServiceRolloutRequest],
+        Awaitable[operations_pb2.Operation],
     ]:
         r"""Return a callable for the create service rollout method over gRPC.
 
@@ -645,7 +652,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["create_service_rollout"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/CreateServiceRollout",
                 request_serializer=servicemanager.CreateServiceRolloutRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_service_rollout"]
 
@@ -693,7 +700,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def enable_service(
         self,
     ) -> Callable[
-        [servicemanager.EnableServiceRequest], Awaitable[operations.Operation]
+        [servicemanager.EnableServiceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the enable service method over gRPC.
 
@@ -719,7 +726,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["enable_service"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/EnableService",
                 request_serializer=servicemanager.EnableServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["enable_service"]
 
@@ -727,7 +734,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
     def disable_service(
         self,
     ) -> Callable[
-        [servicemanager.DisableServiceRequest], Awaitable[operations.Operation]
+        [servicemanager.DisableServiceRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the disable service method over gRPC.
 
@@ -753,7 +760,7 @@ class ServiceManagerGrpcAsyncIOTransport(ServiceManagerTransport):
             self._stubs["disable_service"] = self.grpc_channel.unary_unary(
                 "/google.api.servicemanagement.v1.ServiceManager/DisableService",
                 request_serializer=servicemanager.DisableServiceRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["disable_service"]
 
